@@ -1,6 +1,5 @@
 #! /usr/bin/env perl
 use strict; use warnings;
-use lib "../lib/";
  use Term::Graille  qw/colour paint printAt clearScreen border/;
  use Term::Graille::Font  qw/loadGrf fontWrite/;
  use Time::HiRes "sleep";
@@ -15,8 +14,6 @@ use lib "../lib/";
 clearScreen();  
 
 my $grf=loadGrf("./fonts/ZX Times.grf");
-sleep 20;
-
 logo();
 turtle();
 cube();
